# Generated by roxygen2: do not edit by hand

export(annual_cost)
export(collective_treatment_cost_calculation)
export(create_random_distribution)
export(create_scenario)
export(create_scenario_from_df)
export(dalys_calculation)
export(distribution_repeater)
export(dr.betapoisson)
export(dr.expo)
export(enumeration)
export(final_dose_calculation)
export(generate_random_values)
export(get_exposure_value_or_stop)
export(get_infection_prob)
export(get_risk_total)
export(get_scheme_events_wide)
export(get_tbl_risk)
export(get_treatment_data)
export(illness_probability_calculation)
export(infection_probability_calculation)
export(inflow_concentration)
export(inflow_concentration_custom)
export(initial_dose_calculation)
export(irrigation_need_calculation)
export(percentage_irrigation_need)
export(perimeter_calculation)
export(plot_comparison_qmra_initial_vs_supplementary_processes)
export(plot_dalys)
export(plot_infection_probability)
export(plot_inflow)
export(plot_logreduction)
export(plot_volumes)
export(process_cost_calculation)
export(query_barrier)
export(query_crop)
export(query_crop_height)
export(query_exp_path)
export(query_frequency)
export(query_irrigation_need)
export(query_matrix)
export(query_pathogen)
export(query_pop)
export(query_volume)
export(regulation_matrix_concentration)
export(regulation_matrix_log)
export(retrieve_specific_barrier)
export(run_economic_analysis)
export(run_qmra_custom)
export(run_qmra_initial_situation)
export(run_qmra_learning_case)
export(run_qmra_supplementary_process)
export(simulate_exposure)
export(simulate_inflow)
export(simulate_treatment)
export(total_area_calculation)
export(total_investment_cost)
export(total_irrigation_need)
export(update_concentration)
export(update_frequency)
export(update_frequency_with_desired_value)
export(update_logreduction_decay)
export(update_logreduction_path)
export(update_logreduction_specific_barrier)
export(update_monte_carlo)
export(update_pathogen)
export(update_treatment_scheme)
export(update_volume)
export(update_volume_with_desired_value)
export(water_price)
import(colorspace)
import(cowplot)
import(dplyr)
import(formattable)
import(ggplot2)
importFrom(EnvStats,rtri)
importFrom(dplyr,case_when)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,pick)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(formattable,formattable)
importFrom(plyr,rbind.fill)
importFrom(purrr,imap)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,pmap)
importFrom(readxl,read_excel)
importFrom(rlang,.data)
importFrom(sfsmisc,lseq)
importFrom(stats,qnorm)
importFrom(stats,rlnorm)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stringr,str_wrap)
importFrom(tibble,tibble)
importFrom(tidyr,gather)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,unnest)
importFrom(utils,globalVariables)
