# WARNING - Generated by {fusen} from dev/flat_kwb_infection.Rmd: do not edit by hand # nolint: line_length_linter.

#' Dose-response model: beta-poisson
#'
#' @param dose vector of dose data (default: 
#'   \code{sfsmisc::lseq(from = 0.1, to = 10^10, length = 1000)})
#' @param alpha  alpha (default: 3.28E-01)
#' @param N50  N50 (default: 5.43E+03)
#' @return tibble
#' @export
#' @importFrom sfsmisc lseq
#' @references Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
#'   URL: \url{https://github.com/kwb-r/kwb.utils}
#'   (MIT Licence)
#' 
dr.betapoisson <- function(
  dose = sfsmisc::lseq(from = 1, to = 10^10, length = 1000), 
  alpha = 3.28E-01,
  N50 = 5.43E+03
)
{
  dplyr::as_tibble(data.frame(
    model = "betapoisson",
    dose = dose, 
    infectionProbability = 1 - (1 + dose * (2 ^ (1/alpha) - 1)/N50) ^ -alpha, 
    alpha = alpha, 
    N50 = N50
  ))
}
