# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("catNewLineIf works correctly", {
  # Test that catNewLineIf prints a new line when condition is TRUE
  output <- capture.output(catNewLineIf(TRUE))
  expect_equal(output, "")

  # Test that catNewLineIf doesn't print a new line when condition is FALSE
  output <- capture.output(catNewLineIf(FALSE))
  expect_equal(output, character(0))
})
