# WARNING - Generated by {fusen} from dev/flat_economic.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("total_irrigation_need works", {
  scenario_apprentissage <- create_scenario(
    system.file("input_1culture_2pop.xlsx", package = "ambre")
  )
  irrigation_need <- irrigation_need_calculation(scenario_apprentissage)
  result <- total_irrigation_need(irrigation_need)
  expect_equal(object = result,
               expected = 222500 ) 
})
