# WARNING - Generated by {fusen} from dev/flat_economic.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("water_price works", {
  scenario_apprentissage <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)
  irrigation_need <- irrigation_need_calculation(scenario_apprentissage)
  result <- water_price(scenario = irrigation_need,
            price_per_m3 = 0.01,
            membership_fee = 200)
  expect_true(all(c("water_charge", "annual_membership_fee") %in% names(result))) 
})
