# WARNING - Generated by {fusen} from dev/flat_simulate_treatment.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("get_treatment_data returns correct structure", {
  scenario_test <- create_scenario(
    system.file("input_1culture_2pop.xlsx", package = "ambre")
  )
  scenario_updated <- update_pathogen(scenario = scenario_test,
   pathoName = c("Campylobacter jejuni", "Rotavirus"))
  config = scenario_updated$config[[1]]
  test_processes <- config$treatment$processes

  # Test with include_paras = FALSE
  result_events <- get_treatment_data(test_processes, n_repeatings = 2, n_events = 3,
   debug = FALSE, include_paras = FALSE)
  expect_equal(nrow(result_events), 504) # 84 processes * 2 repeatings * 3 events
  expect_true(all(c("logreduction", "TreatmentID", "PathogenGroup") %in% colnames(result_events)))
})
