# WARNING - Generated by {fusen} from dev/flat_economic.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("total_area_calculation works", {
  scenario_apprentissage <- create_scenario(
    system.file("input_1culture_2pop.xlsx", package = "ambre")
  )
  result <- total_area_calculation(scenario = scenario_apprentissage)
  expect_equal(object = result, 
               expected = 45) 
})
