# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("query_barrier works", {
  expect_equal(object = query_barrier(barrierName = "Q.1 - Activated Sludge"),
               expected = 1)
  expect_equal(object = query_barrier(barrierName = "P.9 - Peeling, P.7 - Cooking"),
               expected = c(14, 16))
  expect_equal(object = query_barrier(barrierName = NA),
               expected = NA)
  expect_error(object = query_barrier(barrierName = "Activated Sludge"),
               regexp = "Barrier name doesn't exist")
})
