# WARNING - Generated by {fusen} from dev/flat_qmra.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("run_qmra_learning_case works", {
  result <- run_qmra_learning_case()
  expect_equal(object = names(result),
               expected = c("concentration", "volume", "logreduction", 
                            "dalys", "regul_matrix_log", "regul_matrix_concentration", "economic")) 
})
