# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

#' Query frequency
#' 
#' Retrieve min and max frequency values according to path defined in the scenario (database ambre_frequence)
#' @param pathID integer ID of the path for which we want to retrieve the frequency values
#' @importFrom dplyr filter select
#' @return frequency
#' 
#' @export
#' @examples
#' scenario_example <- create_scenario(
#'   system.file("input_1culture_2pop.xlsx", package = "ambre")
#' )
#'
#' query_frequency(pathID = scenario_example$PathID)
query_frequency <- function(pathID){
    frequency <- config_ambre$path$frequency |> dplyr::filter(PathID %in% pathID) |>
        dplyr::select(min, max)
    return(frequency)
}
