# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("query_frequency works", {
  scenario_example <- create_scenario(
    system.file("input_1culture_2pop.xlsx", package = "ambre")
  )
  expected_result <- c("min", "max")
  expect_equal(object = colnames(query_frequency(scenario_example$PathID)),
               expected = expected_result)
})
