# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("simulate_inflow works", {
  scenario_test <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))
  scenario_updated <- update_pathogen(scenario = scenario_test, pathoName = c("Campylobacter jejuni"))

  result_1 <- simulate_inflow(config = scenario_updated$config[[1]], debug = FALSE)

  expect_equal(object = result_1$paras,
               expected = structure(list(type = "uniform", repeatings = 1000, events = 365,
    min = 100, max = 5000, PathogenID = 1, PathogenName = "Campylobacter jejuni",
    PathogenGroup = "Bacteria"), class = "data.frame", row.names = c(NA,
-1L)))
})
