# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("query_exp_path works", {
  expect_equal(object = query_exp_path(pathName = "Consumption of the final product potatoes"),
               expected = 12)
})

test_that("query_path errors", {
  expect_error(object = query_exp_path(pathName = "Consumption of the final product"),
               regexp = "Path name doesn't exist")
})

