# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("default_max works correctly", {
  # Test with org_max > 0
  expect_equal(default_max(2, 0.01, f = log10), log10(2))

  # Test with org_max == 0
  expect_equal(default_max(0, 0.01, f = log10), log10(0.01))

  # Test with no transformation function
  expect_equal(default_max(2, 0.01), 2)

  # Test with log transformation
  expect_equal(default_max(2, 0.01, f = log), log(2))

  # Test with org_max == 0 and no transformation function
  expect_equal(default_max(0, 0.01), 0.01)
})

