# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

#' Helper function: gets number of exposures from config
#' 
#' This function does the same thing as kwb.utils::number_of_exposures(),
#' but it is bundled with *ambre* to avoid a hard dependency on the
#' unmaintained package.
#' 
#' @param config list config
#' @return number_of_exposure
#' @references
#'   Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
#'   URL: \url{https://github.com/kwb-r/kwb.utils}
#'   (MIT Licence)
#' @noRd 
#' @examples
#' number_of_exposures(config = config_ambre)
number_of_exposures <- function(config)
{
  # HARD CODED: number_of_exposures MUST be of type value!      
  get_exposure_value_or_stop(config, "number_of_exposures")
}
