# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("number_of_exposures works", {
  expect_equal(object = number_of_exposures(config = config_ambre), 
               expected = 365) 
})
