# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

#' Message on Available Elements
#'
#' This function does the same thing as kwb.utils::hintAvailable(),
#' but it is bundled with *ambre* to avoid a hard dependency on the
#' unmaintained package.
#'
#' @param x names of elements that are available
#' @param type type of element to appear in the message. Default: "element"
#' @param sorted logical. Whether or not to print the available elements in
#'   lexical order. Default: \code{TRUE}
#' @param suffix suffix to be appended to \code{type}. Can be used to
#'   distinguish between singular and plural form. Default: \code{""}
#' @references
#'   Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
#'   URL: \url{https://github.com/kwb-r/kwb.utils}
#'   (MIT Licence)
#' @noRd
#' @examples
#' # Example usage of hintAvailable
#' cat(hintAvailable(c("a", "b", "c"), type = "element"))
#' cat(hintAvailable(c("x", "y"), type = "element", suffix = "s"))
hintAvailable <- function(x, type = "element", sorted = TRUE, suffix = "")
{
  paste0("Available ", enumeration(x, type, sorted, suffix))
}
