# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("hintAvailable works correctly", {
  # Test with single element
  expect_equal(
    hintAvailable("x", type = "element"),
    "Available element:\n- 'x'\n"
  )

  # Test with multiple elements
  expect_equal(
    hintAvailable(c("x", "y"), type = "element", suffix = "s"),
    "Available elements (sorted)s:\n- 'x'\n- 'y'\n"
  )

  # Test with sorted = FALSE
  expect_equal(
    hintAvailable(c("b", "a"), type = "item", sorted = FALSE),
    "Available items:\n- 'b'\n- 'a'\n"
  )

  # Test with numeric vector
  expect_equal(
    hintAvailable(1:3),
    "Available elements (sorted):\n- 1\n- 2\n- 3\n"
  )

  # Test with logical vector
  expect_equal(
    hintAvailable(c(TRUE, FALSE)),
    "Available elements (sorted):\n- FALSE\n- TRUE\n"
  )
})
