# WARNING - Generated by {fusen} from dev/flat_kwb_infection.Rmd: do not edit by hand # nolint: line_length_linter.

#' Dose-response model: exponential
#' 
#' @param dose vector of dose data (default: 
#'   \code{sfsmisc::lseq(from = 0.1, to = 10^10, length = 1000)})
#' @param k k-value (default: 5.72E-01)
#' @return tibble
#' @export
#' @importFrom sfsmisc lseq
#' @references Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
#'   URL: \url{https://github.com/kwb-r/kwb.utils}
#'   (MIT Licence)
#' 
dr.expo <- function(
  dose = sfsmisc::lseq(from = 1, to = 10^10, length = 1000), 
  k = 5.72E-01
)
{
  dplyr::as_tibble(data.frame(
    model = "exponential", 
    dose = dose, 
    infectionProbability = 1 - exp(-k * dose),
    k = k
  ))
}
