# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("update_pathogen works with", {
  scenario_test <- create_scenario(
    system.file("input_1culture_2pop.xlsx", package = "ambre")
  )
  scenario_updated <- update_pathogen(scenario = scenario_test,
   pathoName = c("Campylobacter jejuni", "Rotavirus"))
  
  expect_equal(object = scenario_updated$config[[1]]$inflow$simulate[[1]],
               expected = 1)
  expect_equal(object = scenario_updated$config[[1]]$inflow$simulate[[26]],
               expected = 1)
})

