# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("query_pathogen works", {
  expect_equal(object = query_pathogen(pathogenName = "Campylobacter jejuni"),
               expected = 1)
})

test_that("query_pathogen error", {
  expect_error(object = query_pathogen(pathogenName = "Wrong Pathogen"),
               regexp = "Pathogen name doesn't exist")
})
