# WARNING - Generated by {fusen} from dev/flat_qmra.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("run_qmra_initial_situation works", {
  scenario <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))
  regulation_reduction <- config_ambre$regulation$regulation_value |> dplyr::filter(Country == "France") |>
                          dplyr::select(-c(Concentration, Country, RegulationID))
  regulation_concentration <- config_ambre$regulation$regulation_value |> dplyr::filter(Country == "France") |>
                          dplyr::select(-c(Country, RegulationID, Reduction))
  result <- run_qmra_initial_situation(scenario = scenario, 
                     pathogen = c("Campylobacter jejuni", "Escherichia coli"),
                     regulationLog = regulation_reduction,
                     regulationConcentration = regulation_concentration)
  expect_equal(object = names(result),
               expected = c("logreduction", "dalys", "regul_matrix_log", "regul_matrix_concentration"))
})
