# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

#' Shortcut to paste(x, collapse = collapse)
#' 
#' This is just a shortcut to paste(x, collapse = collapse)
#' 
#' This function does the same thing as kwb.utils::collapsed(),
#' but it is bundled with *ambre* to avoid a hard dependency on the 
#' unmaintained package.
#'
#' @param x vector of character
#' @param collapse character string to separate the elements in x (passed to 
#'   \code{\link[base]{paste}})
#' @references
#'   Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
#'   URL: \url{https://github.com/kwb-r/kwb.utils}
#'   (MIT Licence)
#' @noRd
#' 
#' @examples
#'
#' cat(collapsed(c("apple", "banana", "cherry"), collapse = ", "), "\n")
#' cat(collapsed(c("red", "green", "blue"), collapse = "; "), "\n")
collapsed <- function(x, collapse = " ")
{
  paste(as.character(x), collapse = collapse)
}
