# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("collapsed works correctly", {
  # Test with default collapse
  expect_equal(collapsed(c("a", "b", "c")), "a b c")

  # Test with custom collapse
  expect_equal(collapsed(c("a", "b", "c"), collapse = ", "), "a, b, c")

  # Test with single element
  expect_equal(collapsed(c("a")), "a")

  # Test with empty vector
  expect_equal(collapsed(character(0)), "")

  # Test with numeric vector
  expect_equal(collapsed(1:3), "1 2 3")

  # Test with logical vector
  expect_equal(collapsed(c(TRUE, FALSE)), "TRUE FALSE")
})
