# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.


test_that("get_percentile works correctly", {
  # Test with default parameter
  expect_equal(get_percentile(), qnorm(0.9 + (1 - 0.9) / 2))

  # Test with custom parameter
  expect_equal(get_percentile(0.95), qnorm(0.95 + (1 - 0.95) / 2))

  # Test with edge case (0)
  expect_equal(get_percentile(0), qnorm(0 + (1 - 0) / 2))

  # Test with edge case (1)
  expect_equal(get_percentile(1), qnorm(1 + (1 - 1) / 2))
})

