# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("query_crop_height works", {
  expect_equal(object = query_crop_height("Tomato"),
               expected = 25)
})
