# WARNING - Generated by {fusen} from dev/flat_plots.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("plot_inflow works", {
  scenario_test <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))
  scenario_with_inflow <- inflow_concentration(scenario = scenario_test,
   pathogenName = c("Campylobacter jejuni", "Norovirus"))
  result <- plot_inflow(scenario_with_inflow)
  expect_s3_class(result, "ggplot")
})
