# WARNING - Generated by {fusen} from dev/flat_qmra.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("inflow_concentration works", {
  scenario_test <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))
  result <- inflow_concentration(scenario = scenario_test,
   pathogenName = c("Campylobacter jejuni", "Norovirus"))
  expect_true("inflow_concentration" %in% colnames(result))
})
