# WARNING - Generated by {fusen} from dev/flat_plots.Rmd: do not edit by hand # nolint: line_length_linter.

library(dplyr)
library(purrr)
test_that("plot_volumes works", {
  scenario_test <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))

  scenario_conc <- inflow_concentration(scenario = scenario_test,
   pathogenName = c("Campylobacter jejuni"))
  
  scenario_volume <-
    scenario_conc |>                     
    mutate(
      volume = map(
        .x = config,                                         
        .f = ~ simulate_exposure(config = .x)              
      )
    )
  
  result <- plot_volumes(scenario_volume)
  expect_s3_class(result, "ggplot")
})
