# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("get_exposure_value_or_stop works", {
  expect_equal(object = get_exposure_value_or_stop(config_ambre, "number_of_exposures"),
               expected = 365) 
})
