# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("enumeration works correctly", {
  # Test with default parameters
  expect_equal(
    enumeration(c("a", "b", "c")),
    "elements:\n- 'a'\n- 'b'\n- 'c'\n"
  )

  # Test with custom type
  expect_equal(
    enumeration(c("x", "y"), type = "item"),
    "items:\n- 'x'\n- 'y'\n"
  )

  # Test with sorted = TRUE
  expect_equal(
    enumeration(c("c", "a", "b"), sorted = TRUE),
    "elements (sorted):\n- 'a'\n- 'b'\n- 'c'\n"
  )

  # Test with suffix
  expect_equal(
    enumeration(c("x", "y"), suffix = "s"),
    "elementss:\n- 'x'\n- 'y'\n"
  )

  # Test with single element
  expect_equal(
    enumeration(c("a")),
    "element:\n- 'a'\n"
  )

  # Test with empty vector
  expect_equal(
    enumeration(character(0)),
    "element:\n- ''\n"
  )

  # Test with numeric vector
  expect_equal(
    enumeration(1:3),
    "elements:\n- 1\n- 2\n- 3\n"
  )

  # Test with logical vector
  expect_equal(
    enumeration(c(TRUE, FALSE)),
    "elements:\n- TRUE\n- FALSE\n"
  )
})
