# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("isNullOrEmpty works correctly", {
  # Test NULL
  expect_true(isNullOrEmpty(NULL))

  # Test empty vector
  expect_true(isNullOrEmpty(c()))

  # Test empty list
  expect_true(isNullOrEmpty(list()))

  # Test empty data frame
  expect_true(isNullOrEmpty(data.frame()))

  # Test non-empty vector
  expect_false(isNullOrEmpty(c(1, 2, 3)))

  # Test non-empty list
  expect_false(isNullOrEmpty(list(1, 2, 3)))

  # Test non-empty data frame
  expect_false(isNullOrEmpty(data.frame(a = 1:3, b = letters[1:3])))
})
