# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("query_pop works", {
  expect_equal(object = query_pop(popName = "Irrigation staff"), 
               expected = 1) 
})

test_that("query_pop errors", {
  expect_error(object = query_pop(popName = "Maintainer"),
               regexp = "Population name doesn't exist")
})
