# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("update_monte_carlo works", {
  scenario_example <- create_scenario(
    system.file("input_1culture_2pop.xlsx", package = "ambre")
  )
  scenario_updated <- update_monte_carlo(scenario = scenario_example, 
                     monte_carlo = 2000)
  
  difference <- scenario_updated$config[[1]]$exposure$value[[1]] - scenario_example$config[[1]]$exposure$value[[1]]
  scenario_updated$config[[1]]$exposure
  expect_equal(object = difference,
               expected = 1000) 
})
