# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("get_stop_text works", {
  expect_equal(object = get_stop_text("must_be_value"),
               expected = "%s in configuration 'exposure' MUST be of 'type' = 'value' and column 'value' has to be numeric") 
})
