# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("update_volume_with_desired_value works", {
  scenario_example <- create_scenario(
    system.file("input_1culture_2pop.xlsx", package = "ambre")
  )
  volumes <- data.frame("min" = c(1.1, 1.2), "max" = c(1.3,1.4), "type" = c("triangle", "triangle"))
  result <- update_volume_with_desired_value(scenario = scenario_example,
                                 volume = volumes)
  expect_equal(object = result$config[[1]]$exposure$min[[3]], 
               expected = 1.1) 
  expect_equal(object = result$config[[1]]$exposure$max[[3]], 
               expected = 1.3) 
  
  expect_equal(object = result$config[[2]]$exposure$min[[3]], 
               expected = 1.2) 
  expect_equal(object = result$config[[2]]$exposure$max[[3]], 
               expected = 1.4)
})
