# WARNING - Generated by {fusen} from dev/flat_qmra.Rmd: do not edit by hand # nolint: line_length_linter.

#' Dalys calculation
#' 
#' Calculate dalys lose per event according to illness probability
#' @param scenario data.frame scenario with risk column
#' @return scenario_updated
#' 
#' @export
#' @examples
#' library(dplyr)
#' library(purrr)
#' scenario_test <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))
#'
#' scenario_conc <- inflow_concentration(scenario = scenario_test,
#'  pathogenName = c("Campylobacter jejuni"))
#'
#' scenario_volume <-
#'   scenario_conc |>                     
#'   mutate(
#'     volume = map(
#'       .x = config,                                         
#'       .f = ~ simulate_exposure(config = .x)              
#'     )
#'   )
#'
#' scenario_dose_ini <- initial_dose_calculation(scenario_volume)
#'
#' scenario_scheme <- update_treatment_scheme(scenario_dose_ini)
#'
#' scenario_with_logreduc_and_co <- scenario_scheme |> 
#'   mutate( log_reduction = map(config, simulate_treatment))
#'
#' scenario_final_dose_and_co_test <- final_dose_calculation(scenario_with_logreduc_and_co)
#'
#' scenario_inf_proba_and_co <- infection_probability_calculation(scenario_final_dose_and_co_test)
#'
#' scenario_illness_proba_and_co <- illness_probability_calculation(scenario_inf_proba_and_co)
#'
#' dalys_calculation(scenario_illness_proba_and_co)
dalys_calculation <- function(scenario){
  risk_illness <- map(.x = scenario$risk, .f = ~mutate(.x, dalys_per_event = .x$illnessProb_per_event * .x$dalys_per_case * .$fraction_susceptibilite))
  
  scenario_updated <- scenario |> 
    mutate(risk = risk_illness)
    
}
