# WARNING - Generated by {fusen} from dev/flat_plots.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("plot_comparison_qmra_treatment_vs_barrier works", {
  scenario_test <- create_scenario(
    filepath = system.file("input_1culture_2pop.xlsx", package = "ambre")
  )
  regulation_reduction <- config_ambre$regulation$regulation_value |> dplyr::filter(Country == "France") |>
                          dplyr::select(-c(Concentration, Country, RegulationID))
  regulation_concentration <- config_ambre$regulation$regulation_value |> dplyr::filter(Country == "France") |>
                          dplyr::select(-c(Country, RegulationID, Reduction))
  
  result <- plot_comparison_qmra_initial_vs_supplementary_processes(
    scenario = scenario_test,
    pathogen = c("Campylobacter jejuni"),
    regulationLog = regulation_reduction,
    regulationConcentration = regulation_concentration)
  expect_equal(object = names(result),
               expected = c("log_reduction", "dalys")) 
})
