# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("id_columns_to_integer works", {
  data_test <- data.frame(PathogenID = c(5.5))

  expect_equal(object = id_columns_to_integer(data_test), 
               expected = structure(list(PathogenID = 5L), row.names = c(NA, -1L), class = "data.frame")) 
})
