# WARNING - Generated by {fusen} from dev/flat_economic.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("query_irrigation_need works", {
  scenario_apprentissage <- create_scenario(
    system.file("input_1culture_2pop.xlsx", package = "ambre")
  )
  result <- query_irrigation_need(scenario_apprentissage)
  expect_true("IrrigationNeed" %in% names(result)) 
})
