utils::globalVariables(unique(c(
# update_concentration : 
"max.x", "max.y", "min.x", "min.y", "type.x", "type.y", 
# previously declared:
".x", "allocation", "annual_cost", "annual_fee", "annual_membership_fee", "Area", "capex", "capex_barrier", "capex_barrier_20y", "capex_collective_treatment", "capex_supplementaryProcess", "capex_supplementaryProcess_20y", "Class", "collective_opex", "CollectiveTreatmentID", "CollectiveTreatmentName", "color", "Concentration", "config", "config_ambre", "cost_type", "CostType", "Country", "CropHeight", "CropID", "CropName", "dalys_total", "infectionProb_total", "inflow", "initial_dose", "InitialProcessID", "InitialProcessName", "irrigation_need_m3an", "IrrigationNeed", "loan_asa", "logReduction", "MatrixID", "max_reductionC_achieve", "new_membership_fee", "new_water_charge", "opex", "opex_barrier", "opex_supplementaryProcess", "PathDescription", "PathID", "PathName", "PathogenGroup", "PathogenID", "PathogenName", "PopulationID", "PopulationName", "Reduction", "RegulationID", "risk_total", "STEPtreatmentID", "STEPtreatmentName", "SupplementaryBarrierID", "SupplementaryBarrierName", "SupplementaryProcessID", "SupplementaryProcessName", "SupplementaryTreatmentID", "SupplementaryTreatmentName", "target_class", "total_annual_cost", "total_capex", "TreatmentID", "TreatmentName", "value", "volume", "volume_perEvent", "volume_to_treat", "water_charge"
)))
