# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

#' String of Comma Separated Quoted Strings
#' 
#' Create a string of comma separated quoted strings
#' 
#' This function does the same thing as kwb.utils::stringList(),
#' but it is bundled with *ambre* to avoid a hard dependency on the 
#' unmaintained package.
#' 
#' @param x vector of character
#' @param qchar character to be used for quoting, default: single quote
#'   character
#' @param collapse characters used to separate the strings. Default: ", "
#' @references
#'   Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
#'   URL: \url{https://github.com/kwb-r/kwb.utils}
#'   (MIT Licence)
#' @noRd
#' 
#' @examples
#'
#' # cat(stringList(c("apple", "banana", "cherry"), qchar = "\""), "\n")
#' # cat(stringList(c("red", "green", "blue"), qchar = "'", collapse = "; "), "\n")
stringList <- function(x, qchar = "'", collapse = ", ") 
{
  collapsed(hsQuoteChr(x, qchar = qchar), collapse = collapse)
}
