# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("stringList works correctly", {
  # Test with default parameters
  expect_equal(stringList(c("a", "b", "c")), "'a', 'b', 'c'")

  # Test with custom quote character
  expect_equal(stringList(c("a", "b", "c"), qchar = "\""), "\"a\", \"b\", \"c\"")

  # Test with custom collapse
  expect_equal(stringList(c("a", "b", "c"), collapse = "; "), "'a'; 'b'; 'c'")

  # Test with single element
  expect_equal(stringList(c("a")), "'a'")

  # Test with empty vector
  expect_equal(stringList(character(0)), "''")

  # Test with numeric vector
  expect_equal(stringList(1:3), "1, 2, 3")

  # Test with logical vector
  expect_equal(stringList(c(TRUE, FALSE)), "TRUE, FALSE")
})
