# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

#' Query Matrix
#' 
#' Retrieve Matrix ID according to path 
#' @param config list configuration file default value is config_ambre dataset
#' @param pathName character Name of the path for which you want to find the ID
#' @importFrom dplyr filter pull
#' @return matrixID integer
#' 
#' @export
#' @examples
#' query_matrix(pathName = "Consumption of the final product potatoes")
query_matrix <- function(config = config_ambre, pathName){
  matrixID <- config_ambre$path$description |> filter(PathDescription %in% pathName) |> 
                                          pull(MatrixID)
  return(matrixID)
}
