# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("query_matrix works", {
  result <- query_matrix(pathName = "Consumption of the final product potatoes")
  expect_equal(object = result, 
               expected = 5) 
})
