# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

#' Call cat If Condition Is Met
#' 
#' This function does the same thing as kwb.utils::catIf(),
#' but it is bundled with *ambre* to avoid a hard dependency on the 
#' unmaintained package.
#' 
#' @param condition if TRUE, cat is called, else not
#' @param \dots arguments passed to cat
#' @references
#'   Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
#'   URL: \url{https://github.com/kwb-r/kwb.utils}
#'   (MIT Licence)
#' @noRd
#' 
#' @examples
#'
#' catIf(TRUE, "This will be printed\n")
#' catIf(FALSE, "This will not be printed\n")
catIf <- function(condition, ...)
{
  if (condition) {
    
    cat(...)
  }
}
