# WARNING - Generated by {fusen} from dev/flat_kwb_simulate_inflow.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("catIf works correctly", {
  # Test that catIf prints when condition is TRUE
  output <- capture.output(catIf(TRUE, "Test message"))
  expect_equal(output, "Test message")

  # Test that catIf doesn't print when condition is FALSE
  output <- capture.output(catIf(FALSE, "Test message"))
  expect_equal(output, character(0))
})
