# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

#' Query volume
#' 
#' Retrieve min and max volume values according to path defined in the scenario (database ambre_volume)
#' @param pathID integer ID of the path for which we want to retrieve the volume min and max values
#' @importFrom dplyr filter select
#' @return volume
#' 
#' @export
#' @examples
#' query_volume(pathID = 1)
query_volume <- function(pathID){
    volume <- config_ambre$path$volume |> dplyr::filter(PathID %in% pathID) |>
        dplyr::select(min, max)
    return(volume)
}
