# WARNING - Generated by {fusen} from dev/flat_scenario.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("query_volume works", {
  expected_result <- c("min", "max")
  expect_equal(object = colnames(query_volume(pathID = 1)),
               expected = expected_result)
})
