# WARNING - Generated by {fusen} from dev/flat_qmra.Rmd: do not edit by hand # nolint: line_length_linter.

test_that("inflow_concentration_custom works", {
  expect_true(inherits(inflow_concentration_custom, "function")) 
})
