% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/inflow_concentration.R
\name{inflow_concentration}
\alias{inflow_concentration}
\title{Inflow concentration}
\usage{
inflow_concentration(scenario, pathogenName, monteCarlo = 1000)
}
\arguments{
\item{scenario}{list scenario created with create_scenario}

\item{pathogenName}{character names of the pathogens to be simulated}

\item{monteCarlo}{integer number of simulation iterations for Monte Carlo}
}
\value{
scenario_with_concentration
}
\description{
To calculate inflow concentration for specified pathogen
}
\examples{
scenario_test <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))
result <- inflow_concentration(scenario = scenario_test,
 pathogenName = c("Campylobacter jejuni", "Norovirus"),
 monteCarlo = 2000)

}
