% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_inflow.R
\name{plot_inflow}
\alias{plot_inflow}
\title{Plot inflow concentration}
\usage{
plot_inflow(scenario)
}
\arguments{
\item{scenario}{data.frame with inflow_concentration column obtained from inflow_concentration function}
}
\value{
plot
}
\description{
Violin plot of inflow concentration according to pathogen simulated
}
\examples{
scenario_test <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))
scenario_with_inflow <- inflow_concentration(scenario = scenario_test,
 pathogenName = c("Campylobacter jejuni", "Norovirus"))
plot_inflow(scenario_with_inflow)
}
