% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/perimeter_calculation.R
\name{perimeter_calculation}
\alias{perimeter_calculation}
\title{Perimeter calculation}
\usage{
perimeter_calculation(scenario)
}
\arguments{
\item{scenario}{data.frame scenario obtained with create_scenario function}
}
\value{
scenario_updated
}
\description{
Calculate perimeter (linear meter) according to surface, and add the value to the scenario dataframe
}
\examples{
scenario_apprentissage <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)

scenario_apprentissage_updated <- perimeter_calculation(scenario_apprentissage)
print(scenario_apprentissage_updated$perimeter)
}
