% Generated by roxygen2: do not edit by hand
% Please edit documentation in
%   R/plot_comparison_qmra_initial_vs_supplementary_processes.R
\name{plot_comparison_qmra_initial_vs_supplementary_processes}
\alias{plot_comparison_qmra_initial_vs_supplementary_processes}
\title{Plot comparison QMRA calculation with initial vs supplementary processes}
\usage{
plot_comparison_qmra_initial_vs_supplementary_processes(
  scenario,
  pathogen,
  regulationLog,
  regulationConcentration
)
}
\arguments{
\item{scenario}{data.frame, scenario obtained with create_scenario function}

\item{pathogen}{character, Name of the pathogen to simulate}

\item{regulationLog}{data.frame regulation value of the log reduction to compare with simulation result}

\item{regulationConcentration}{data.frame regulation value of the log reduction to compare with simulation result}
}
\value{
combine_plots
}
\description{
Compare the result of the QMRA simulation with reduction_log from initial vs supplementary processes
}
\examples{
\donttest{
library(dplyr)
scenario_example <- create_scenario(
  filepath = system.file("input_1culture_2pop.xlsx", package = "ambre")
)


regulation_reduction <- config_ambre$regulation$regulation_value |> 
  dplyr::filter(Country == "France") |>
  dplyr::select(-c(Concentration, Country, RegulationID))
regulation_concentration <- config_ambre$regulation$regulation_value |> 
  dplyr::filter(Country == "France") |>
  dplyr::select(-c(Country, RegulationID, Reduction))

plot_comparison_qmra_initial_vs_supplementary_processes(
  scenario = scenario_example,
  pathogen = c("Campylobacter jejuni", "Norovirus"),
  regulationLog = regulation_reduction,
  regulationConcentration = regulation_concentration
)
}
}
