% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/enumeration.R
\name{enumeration}
\alias{enumeration}
\title{Enumerate Elements}
\usage{
enumeration(x, type = "element", sorted = FALSE, suffix = "")
}
\arguments{
\item{x}{vector of elements to be enumerated}

\item{type}{type of element to appear in the message. Default: "element"}

\item{sorted}{logical. Whether or not to print the available elements in
lexical order. Default: \code{FALSE}}

\item{suffix}{suffix to be appended to \code{type}. Can be used to
distinguish between singular and plural form. Default: \code{""}}
}
\value{
character string containing the enumeration
}
\description{
This function does the same thing as kwb.utils::enumeration(),
but it is bundled with \emph{ambre} to avoid a hard dependency on the
unmaintained package.
}
\examples{

# Example usage of enumeration
cat(enumeration(c("a", "b", "c"), type = "element"))
cat(enumeration(c("x", "y"), type = "element", suffix = "s"))
}
\references{
Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
URL: \url{https://github.com/kwb-r/kwb.utils}
(MIT Licence)
}
