% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/update_logreduction_path.R
\name{update_logreduction_path}
\alias{update_logreduction_path}
\title{Update log reduction for specific path}
\usage{
update_logreduction_path(config, matrixID, popID, barrierID)
}
\arguments{
\item{config}{list configuration simulated}

\item{matrixID}{numeric, ID of the matrix simulated}

\item{popID}{numeric, ID of the population simulated}

\item{barrierID}{numeric, ID of the barrier simulated}
}
\value{
config_updated
}
\description{
Update the log reduction value for specific barrier according to path and population simulated
}
\examples{
scenario_example <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)

scenario_example$config <- purrr::pmap(
  list(
    config = scenario_example$config,
    barrierID = scenario_example$SupplementaryProcessID,
    matrixID = scenario_example$MatrixID,
    popID = scenario_example$PopulationID
  ),
  function(config, barrierID, matrixID, popID) {

    if (barrierID \%in\% c(9,13,14,15,16,17,18,24,26,27,28)) {

      update_logreduction_path(
        config = config,
        matrixID = matrixID,
        barrierID = barrierID,
        popID = popID
      )

    } else {
      config
    }
  }
)
}
