% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query_crop_height.R
\name{query_crop_height}
\alias{query_crop_height}
\title{Query crop height}
\usage{
query_crop_height(cropName)
}
\arguments{
\item{cropName}{integer, identifier of the crop simulated}
}
\value{
height
}
\description{
Retrieve height of the crop simulated
}
\examples{
query_crop_height("Tomato")
}
