% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simulate_exposure.R
\name{simulate_exposure}
\alias{simulate_exposure}
\title{Simulate: exposure}
\usage{
simulate_exposure(config, debug = TRUE)
}
\arguments{
\item{config}{as retrieved by config_read()}

\item{debug}{print debug information (default: TRUE)}
}
\value{
list with parameters of user defined exposure scenario (number of events
and volumes per Event)
}
\description{
This function does the same thing as kwb.qmra::get_treatment_data(),
but it is bundled with \emph{ambre} to avoid a hard dependency on the
unmaintained package.
}
\examples{
\donttest{
scenario_test <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))
scenario_updated <- update_pathogen(scenario = scenario_test,
 pathoName = c("Campylobacter jejuni", "Rotavirus"))

simulate_exposure(config = scenario_updated$config[[1]])
}
}
\references{
Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
URL: \url{https://github.com/kwb-r/kwb.utils}
(MIT Licence)
}
