% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/update_logreduction_specific_barrier.R
\name{update_logreduction_specific_barrier}
\alias{update_logreduction_specific_barrier}
\title{Update log reduction with specific value}
\usage{
update_logreduction_specific_barrier(config, cropHeight, barrierID)
}
\arguments{
\item{config}{list configuration simulated}

\item{cropHeight}{numeric, height of th crop simulated}

\item{barrierID}{numeric, ID of the barrier simulated}
}
\value{
config_updated
}
\description{
Update log reduction value according to treatment, crop, and population simulated
}
\examples{
scenario_example <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)

scenario_example$config <- purrr::pmap(
  list(
    config = scenario_example$config,
    barrierID = scenario_example$SupplementaryProcessID,
    matrixID = scenario_example$MatrixID,
    cropHeight = scenario_example$CropHeight
  ),
  function(config, barrierID, matrixID, cropHeight) {

    if (barrierID \%in\% c(24, 26, 27, 28) &&
        matrixID \%in\% c(3, 5)) {

      update_logreduction_specific_barrier(
        config = config,
        cropHeight = cropHeight,
        barrierID = barrierID
      )

    } else {
      config
    }
  }
)
}
