% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/total_irrigation_need.R
\name{total_irrigation_need}
\alias{total_irrigation_need}
\title{Total irrigation need}
\usage{
total_irrigation_need(scenario)
}
\arguments{
\item{scenario}{data.frame scenario with irrigation_need_m3an column obtained with irrigation_need_calculation function}
}
\value{
total_irrigation_need
}
\description{
Calculate total irrigation need according to irrigation need of each culture of the simulated scenario
}
\examples{
scenario_apprentissage <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)
irrigation_need <- irrigation_need_calculation(scenario_apprentissage)
total_irrigation_need(irrigation_need)
}
