% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/total_area_calculation.R
\name{total_area_calculation}
\alias{total_area_calculation}
\title{Total area}
\usage{
total_area_calculation(scenario)
}
\arguments{
\item{scenario}{data.frame scenario created with create_scenario function}
}
\value{
surface_total data.frame
}
\description{
Calculate the total area of each culture of the simulated scenario
}
\examples{
scenario_apprentissage <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)
total_area_calculation(scenario = scenario_apprentissage)
}
