% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/update_monte_carlo.R
\name{update_monte_carlo}
\alias{update_monte_carlo}
\title{Update monte carlo value}
\usage{
update_monte_carlo(scenario, monte_carlo = 1000)
}
\arguments{
\item{scenario}{data.frame scenario obtained with create_scenario function}

\item{monte_carlo}{integer number of simulation iterations for Monte Carlo}
}
\value{
scenario_updated
}
\description{
Update number_of_repeating in config$exposure database
}
\examples{
scenario_example <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)
scenario_updated <- update_monte_carlo(scenario = scenario_example, 
                   monte_carlo = 2000)
scenario_updated$config[[1]]$exposure
}
