% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/process_cost_calculation.R
\name{process_cost_calculation}
\alias{process_cost_calculation}
\title{Barrier Cost Calculation}
\usage{
process_cost_calculation(scenario, membership_fee, charge, initialSituation)
}
\arguments{
\item{scenario}{data.frame scenario with irrigation_need_m3an column obtained from irrigation_need_calculation function}

\item{membership_fee}{numeric annual membership fee}

\item{charge}{numeric water charge}

\item{initialSituation}{boolean TRUE to simulate initial simulation cost, FALSE to simulate supplementary process cost}
}
\value{
scenario_updated
}
\description{
Calculate cost of supplementary barriers
}
\examples{
scenario_apprentissage <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre"))
irrigation_need <- irrigation_need_calculation(scenario_apprentissage)
process_cost_calculation(scenario = irrigation_need,
                         membership_fee = 200,
                         charge = 0.1,
                         initialSituation = TRUE)


process_cost_calculation(scenario = irrigation_need,
                         membership_fee = 200,
                         charge = 0.1,
                         initialSituation = FALSE)
}
