% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/water_price.R
\name{water_price}
\alias{water_price}
\title{Water charge}
\usage{
water_price(scenario, price_per_m3, membership_fee)
}
\arguments{
\item{scenario}{data.frame, with irrigation_need_m3an obtained with irrigation_need_calculation function}

\item{price_per_m3}{numeric, water price in euro per cubic meter}

\item{membership_fee}{numeric annual membership fee in euro per hectare}
}
\value{
updated_scenario
}
\description{
Calculate  cost of water charge
}
\examples{


scenario_apprentissage <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)
irrigation_need <- irrigation_need_calculation(scenario_apprentissage)
water_price(scenario = irrigation_need,
            price_per_m3 = 0.01,
            membership_fee = 200)
}
