% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_infection_prob.R
\name{get_infection_prob}
\alias{get_infection_prob}
\title{Get infection probability values}
\usage{
get_infection_prob(tbl_risk, dose_response, health)
}
\arguments{
\item{tbl_risk}{data.frame containing PathogenID and dose_perEvent columns}

\item{dose_response}{data.frame database of dose_response factors presents in config_ambre}

\item{health}{data.frame database of health factors presents in config_ambre}
}
\value{
result_vector
}
\description{
Simulate infection probability according to pathogen consider
}
\references{
Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
URL: \url{https://github.com/kwb-r/kwb.utils}
(MIT Licence)
}
