% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_qmra_learning_case.R
\name{run_qmra_learning_case}
\alias{run_qmra_learning_case}
\title{QMRA on learning case}
\usage{
run_qmra_learning_case()
}
\value{
all_plots list
}
\description{
Run a learning case to evaluate risk on scenario with 6 crops (Corn Seed, Tomato, Potato, Salad, Onion) and 6 populations (maintainer, harverster, irrigation, consumer, local resident, passerby). Run QMRA calculation with barrier measures
}
\examples{
\donttest{
run_qmra_learning_case()
}
}
