% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/doc_config_ambre.R
\docType{data}
\name{config_ambre}
\alias{config_ambre}
\title{config_ambre}
\format{
A list of 3 lists and 5 tibbles :
\describe{
\item{ exposure }{  Exposure condition : number of repeatings for Monte Carlo simulation, number of exposures per year, volume (L) per exposure event }
\item{ inflow }{  Pathogen concentration (number of pathogen per L) }
\item{ treatment }{  Database of log reductions for risk management measures }
\item{ processes }{  General values for the log reductions }
\item{ schemes }{  Risk management process (sequence of measures) assessed }
\item{ barrier_path }{  Specific values for log reductions based on the assessed route of exposure }
\item{ barrier_specific }{  Specific values for log reductions based on the assessed measure }
\item{ barrier_decay }{  Specific values for log reductions for the natural die off measure }
\item{ doseresponse }{  Parameters for dose response model (https://qmrawiki.org/framework/dose-response/highest-quality-models-and-parameters) }
\item{ path }{  Details on pathways of exposure }
\item{ description }{  Description of pathways of exposure }
\item{ frequency }{  Frequency values of pathways of exposure }
\item{ volume }{  Volume values of pathways of exposure }
\item{ crop }{  Description of crop }
\item{ health }{ Parameters for risk characterization  }
\item{ economic }{  Parameters for economic analysis }
\item{ water_need }{  Value of irrigation need according to crop type }
\item{ population }{  Description of population exposed }
\item{ cost }{  Database of opex and capex cost of risk management measures (https://theses.hal.science/tel-05009670) }
\item{ regulation_value }{  Database of required microorganism removal performance (in terms of concentration or removal rate) by regulatory class and pathogen group }
\item{ regulation_crop }{  Database of required water class acording to crop }
}
}
\usage{
config_ambre
}
\description{
A structured database containing the parameters and values needed to perform Quantitative Microbial Risk Assessment (QMRA) and cost calculations.
}
\examples{
names(config_ambre)
}
\keyword{datasets}
