% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query_barrier.R
\name{query_barrier}
\alias{query_barrier}
\title{Barrier Query}
\usage{
query_barrier(config = config_ambre, barrierName, na.rm = FALSE)
}
\arguments{
\item{config}{list configuration file default value is config_ambre dataset}

\item{barrierName}{character Name of the barrier you want to find the ID}

\item{na.rm}{boolean FALSE by default}
}
\value{
barrierID
}
\description{
retrieve Barrier ID according to its name in the barrier database
}
\examples{
query_barrier(barrierName = "Q.1 - Activated Sludge")
query_barrier(barrierName = c("Q.1 - Activated Sludge", "Q.2 - Maturation Pond"))
query_barrier(barrierName = "P.9 - Peeling, P.7 - Cooking")
}
