% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generate_random_values.R
\name{generate_random_values}
\alias{generate_random_values}
\title{Create random distribution based on configuration file}
\usage{
generate_random_values(
  config,
  number_of_repeatings = 1,
  number_of_events,
  debug = TRUE
)
}
\arguments{
\item{config}{as retrieved by config_read()}

\item{number_of_repeatings}{how often should the random distribution with the
same parameters be generated (default: 1)}

\item{number_of_events}{number of events}

\item{debug}{print debug information (default: TRUE)}
}
\value{
list random distributions based on configuration file
}
\description{
This function does the same thing as kwb.utils::generate_random_values(),
but it is bundled with \emph{ambre} to avoid a hard dependency on the
unmaintained package.
}
\examples{
# Example usage of generate_random_values
# Create a sample config object
config <- list(
  type = "norm",
  value = 10,
  min = 5,
  max = 15,
  mean = 10,
  sd = 2,
  meanlog = log(10),
  sdlog = 0.5,
  mode = 10
)

# Call generate_random_values with the sample config
result <- generate_random_values(
  config = config,
  number_of_repeatings = 2,
  number_of_events = 10,
  debug = FALSE
)

# Print the results
cat("Simulated events:")
print(result$events)

cat("Parameters used for simulation:")
print(result$paras)
}
\references{
Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
URL: \url{https://github.com/kwb-r/kwb.utils}
(MIT Licence)
}
