% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query_frequency.R
\name{query_frequency}
\alias{query_frequency}
\title{Query frequency}
\usage{
query_frequency(pathID)
}
\arguments{
\item{pathID}{integer ID of the path for which we want to retrieve the frequency values}
}
\value{
frequency
}
\description{
Retrieve min and max frequency values according to path defined in the scenario (database ambre_frequence)
}
\examples{
scenario_example <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)

query_frequency(pathID = scenario_example$PathID)
}
