% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/irrigation_need_calculation.R
\name{irrigation_need_calculation}
\alias{irrigation_need_calculation}
\title{Irrigation need calculation}
\usage{
irrigation_need_calculation(scenario)
}
\arguments{
\item{scenario}{data.frame scenario obtained with create_scenario function}
}
\value{
scenario_updated
}
\description{
Calculate irrigation need according to irrigation need of the culture simulated and its surface
}
\examples{
scenario_apprentissage <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)
irrigation_need <- irrigation_need_calculation(scenario_apprentissage)
print(irrigation_need$irrigation_need_m3an)
}
