% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_qmra_initial_situation.R
\name{run_qmra_initial_situation}
\alias{run_qmra_initial_situation}
\title{Run QMRA on initial situation}
\usage{
run_qmra_initial_situation(
  scenario,
  pathogen,
  regulationLog,
  regulationConcentration
)
}
\arguments{
\item{scenario}{data.frame scenario obtained with create_scenario function path of the scenario file}

\item{pathogen}{character Name of the pathogen to simulate}

\item{regulationLog}{data.frame regulation value of the log reduction to compare with simulation result}

\item{regulationConcentration}{data.frame regulation value of the log reduction to compare with simulation result}
}
\value{
all_plots list of ggplot
}
\description{
Run the full QMRA workflow
\enumerate{
\item simulate inflow concentration, volume of exposure
\item calculate initial dose
\item simulate log reduction for treatment processes
\item calculate final dose
\item calculate infection probability, illness probability and dalys reduction
\item calculate annual total risk
}
}
\examples{
\donttest{
library(dplyr)
scenario <- create_scenario(system.file("input_cas_apprentissage_complet.xlsx", package = "ambre"))
regulation_reduction <- config_ambre$regulation$regulation_value |> 
  dplyr::filter(Country == "France") |>
  dplyr::select(-c(Concentration, Country, RegulationID))
regulation_concentration <- config_ambre$regulation$regulation_value |> 
  dplyr::filter(Country == "France") |>
  dplyr::select(-c(Country, RegulationID, Reduction))
run_qmra_initial_situation(scenario = scenario, 
                   pathogen = c("Campylobacter jejuni", "Escherichia coli"),
                   regulationLog = regulation_reduction,
                   regulationConcentration = regulation_concentration)
}
}
