% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/update_concentration.R
\name{update_concentration}
\alias{update_concentration}
\title{Update concentration with desired value}
\usage{
update_concentration(scenario, concentration)
}
\arguments{
\item{scenario}{data.frame}

\item{concentration}{data.frame of pathogenName, min, max and distribution law to simulate}
}
\value{
scenario_updated
}
\description{
Update the min, max and distribution law of the concentration in the simulated configuration according to a value defined by the user
}
\examples{
scenario_test <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)

pathogenName <- c("Norovirus", "Rotavirus")
concentration_custom <- data.frame(PathogenName = pathogenName,
                                   min = c(1, 1),
                                   max = c(2,2),
                                   type = c("uniform", "uniform"))

scenario_updated_patho <- update_pathogen(scenario = scenario_test, pathoName = pathogenName)
result <- update_concentration(scenario = scenario_updated_patho ,
                     concentration = concentration_custom)

dplyr::filter(result$config[[1]]$inflow, PathogenName == "Norovirus")

}
