% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/update_frequency_with_desired_value.R
\name{update_frequency_with_desired_value}
\alias{update_frequency_with_desired_value}
\title{Updated frequency with desired value}
\usage{
update_frequency_with_desired_value(scenario, frequency)
}
\arguments{
\item{scenario}{data.frame}

\item{frequency}{numeric, list of max frequency to simulate}
}
\value{
scenario_updated
}
\description{
Update the value of the frequency in the simulated configuration according to a value defined by the user
}
\examples{
scenario_example <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)
scenario_example_updated <- update_frequency_with_desired_value(scenario = scenario_example, 
                                                                frequency = c(2L,3L))
print(scenario_example_updated$config[[1]]$exposure)
print(scenario_example_updated$config[[2]]$exposure)
}
