% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query_crop.R
\name{query_crop}
\alias{query_crop}
\title{Crop Query}
\usage{
query_crop(config = config_ambre, cropName)
}
\arguments{
\item{config}{list configuration file default value is config_ambre dataset}

\item{cropName}{character Name of crop for which you want to find the identifier}
}
\value{
cropID integer
}
\description{
Query to return crop ID from crop Name in crop database
}
\examples{
query_crop(cropName = "Corn seed")
}
