% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query_exp_path.R
\name{query_exp_path}
\alias{query_exp_path}
\title{Path Query}
\usage{
query_exp_path(config = config_ambre, pathName)
}
\arguments{
\item{config}{list configuration file default value is config_ambre dataset}

\item{pathName}{character Name of the path for which you want to find the ID}
}
\value{
pathID integer ID of the population define
}
\description{
Query to return path ID from path Name using the database
}
\examples{
query_exp_path(pathName = "Consumption of the final product potatoes")
}
