% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/update_volume_with_desired_value.R
\name{update_volume_with_desired_value}
\alias{update_volume_with_desired_value}
\title{Update volume with desired value}
\usage{
update_volume_with_desired_value(scenario, volume)
}
\arguments{
\item{scenario}{data.frame}

\item{volume}{numeric, named list of min and max value to simulate}
}
\value{
scenario_updated
}
\description{
Update the min and max value of the volume in the simulated configuration according to a value defined by the user
}
\examples{
scenario_example <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)
volumes <- data.frame("min" = c(1.1, 1.2), "max" = c(1.3,1.4), "type" = c("triangle", "triangle"))
scenario_example_updated <- update_volume_with_desired_value(scenario = scenario_example,
                                 volume = volumes)

print(scenario_example_updated$config[[1]]$exposure)
print(scenario_example_updated$config[[2]]$exposure)
}
