% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_exposure_value_or_stop.R
\name{get_exposure_value_or_stop}
\alias{get_exposure_value_or_stop}
\title{Get exposure value or stop}
\usage{
get_exposure_value_or_stop(config, name)
}
\arguments{
\item{config}{list config}

\item{name}{character name of the column}
}
\value{
value
}
\description{
This function does the same thing as kwb.utils::exposure_value_or_stop(),
but it is bundled with \emph{ambre} to avoid a hard dependency on the
unmaintained package.
}
\details{
Description
}
\examples{
get_exposure_value_or_stop(config_ambre, "number_of_exposures")
}
\references{
Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
URL: \url{https://github.com/kwb-r/kwb.utils}
(MIT Licence)
}
