% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution_repeater.R
\name{distribution_repeater}
\alias{distribution_repeater}
\title{Helper function: distribution repeater}
\usage{
distribution_repeater(
  number_of_repeatings = 10,
  number_of_events = 365,
  func,
  ...
)
}
\arguments{
\item{number_of_repeatings}{how often should the random distribution with the
same parameters be generated (default: 1)}

\item{number_of_events}{number of events (a single positive integer, >= 1)}

\item{func}{distribution function to be repeated (e.g. runif, rlnorm, rnorm)}

\item{...}{further parameters passed to func}
}
\value{
data.frame with columns repeatID, eventID and values
}
\description{
This function does the same thing as kwb.utils::distribution_repeater(),
but it is bundled with \emph{ambre} to avoid a hard dependency on the
unmaintained package.
}
\examples{
 distribution_repeater(
   number_of_repeatings = 2,
   number_of_events = 10,
   func = runif,
   min = 1,
   max = 10
)
}
\references{
Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
URL: \url{https://github.com/kwb-r/kwb.utils}
(MIT Licence)
}
