% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query_pathogen.R
\name{query_pathogen}
\alias{query_pathogen}
\title{Pathogen Query}
\usage{
query_pathogen(config = config_ambre, pathogenName)
}
\arguments{
\item{config}{list configuration file default value is config_ambre dataset}

\item{pathogenName}{character Name of the pathogen for which you want to find the ID}
}
\value{
pathogenID integer ID of the pathogen define
}
\description{
Query to return pathogen ID from pathogen Name using the database
}
\examples{
query_pathogen(pathogenName = "Campylobacter jejuni")

query_pathogen(pathogenName = c("Campylobacter jejuni", "Rotavirus"))

}
