% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/update_volume.R
\name{update_volume}
\alias{update_volume}
\title{Volume update}
\usage{
update_volume(scenario)
}
\arguments{
\item{scenario}{dataframe scenario obtained with function create_scenario}
}
\value{
scenario_updated list configuration updated with the min and max volumes to be simulated
}
\description{
Update the configuration with min and max volumes to be simulated according to path ID
}
\examples{
scenario_example <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)
scenario_updated <- update_volume(scenario_example)
scenario_updated$config[[1]]$exposure
}
