% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ambre-package.R
\docType{package}
\name{ambre-package}
\alias{ambre}
\alias{ambre-package}
\title{ambre: Multi-Barrier Approach for Water Reuse Risk Assessment}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

Provides a Quantitative Microbial Risk Assessment (QMRA) framework for the reuse of treated wastewater in agricultural irrigation. Following a multi-barrier approach, the package simulates pathogen inflow and removal along a treatment train, estimates human exposure, and computes health risk indicators such as infection probability, illness probability, and Disability-Adjusted Life Years (DALYs). It also supports an economic analysis of the treatment scenarios considered. For more details see \doi{10.36904/20240595}.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://forge.inrae.fr/reversaal/reut/ambre-package}
  \item Report bugs at \url{https://forge.inrae.fr/reversaal/reut/ambre-package/-/issues}
}

}
\author{
\strong{Maintainer}: Flora Girard \email{flora.girard@inrae.fr} (\href{https://orcid.org/0000-0003-0537-4530}{ORCID})

Other contributors:
\itemize{
  \item Nicolas Forquet \email{nicolas.forquet@inrae.fr} (\href{https://orcid.org/0000-0003-1154-5498}{ORCID}) [contributor]
  \item Arthur Bréant \email{arthur@thinkr.fr} [contributor]
  \item Colin Fay \email{colin@thinkr.fr} (\href{https://orcid.org/0000-0001-7343-1846}{ORCID}) [contributor]
}

}
\keyword{internal}
