% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/inflow_concentration_custom.R
\name{inflow_concentration_custom}
\alias{inflow_concentration_custom}
\title{Inflow concentration custom}
\usage{
inflow_concentration_custom(scenario, concentration, monteCarlo = 1000)
}
\arguments{
\item{scenario}{list scenario created with create_scenario}

\item{concentration}{data.frame min, max and distribution law of pathogen concentration}

\item{monteCarlo}{integer number of simulation iterations for Monte Carlo}
}
\value{
scenario_with_concentration
}
\description{
To calculate inflow concentration for specified pathogen
}
\examples{
sc <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))
sc  <- update_volume_with_desired_value(sc, 
                                        volume = data.frame(min = c(0.5,1), 
                                                            max = c(1,2), 
                                                            type = c("triangle", "triangle")))
  
sc <- update_frequency_with_desired_value(scenario = sc, frequency = c(200L, 300L))

concentration_custom <- data.frame(PathogenName = c("Campylobacter jejuni", "Norovirus"),
                                   min = c(1, 10),
                                   max = c(2,20),
                                   type = c("uniform", "uniform"))
  
inflow_concentration_custom(scenario = sc,
                            concentration = concentration_custom)
}
