% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_treatment_data.R
\name{get_treatment_data}
\alias{get_treatment_data}
\title{Simulate treatment data for pathogen processes}
\usage{
get_treatment_data(
  processes,
  n_repeatings,
  n_events,
  debug = TRUE,
  include_paras = TRUE
)
}
\arguments{
\item{processes}{A data frame containing information about pathogen processes,
including treatment names and pathogen groups.}

\item{n_repeatings}{The number of times each process should be repeated.}

\item{n_events}{The number of events to simulate for each process.}

\item{debug}{Logical indicating whether to print debug information.}

\item{include_paras}{Logical indicating whether to include parameter data.}
}
\value{
If \code{include_paras} is FALSE, returns a data frame of simulated events.
If \code{include_paras} is TRUE, returns a list containing both the events data frame
and a data frame of parameters.
}
\description{
This function simulates treatment data for a set of pathogen processes, including
random values for each process and optional parameters. It can be used to generate
synthetic data for analysis or testing.
}
\details{
This function does the same thing as kwb.qmra::get_treatment_data(),
but it is bundled with \emph{ambre} to avoid a hard dependency on the
unmaintained package.
}
\examples{
# Example usage (assuming 'processes' is defined)
scenario_test <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)
scenario_updated <- update_pathogen(scenario = scenario_test,
 pathoName = c("Campylobacter jejuni", "Rotavirus"))
config = scenario_updated$config[[1]]
processes_simulated <- config$treatment$processes

result <- get_treatment_data(processes_simulated, n_repeatings = 10, n_events = 5)
print(result)
}
\references{
Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
URL: \url{https://github.com/kwb-r/kwb.utils}
(MIT Licence)
}
