% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query_irrigation_need.R
\name{query_irrigation_need}
\alias{query_irrigation_need}
\title{Query irrigation need}
\usage{
query_irrigation_need(scenario)
}
\arguments{
\item{scenario}{data.frame scenario obtained with create_scenario function}
}
\value{
scenario_updated
}
\description{
Retrieve irrigation need according to crop ID
}
\examples{
scenario_apprentissage <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)

irrigation_need <- query_irrigation_need(scenario_apprentissage)
print(irrigation_need$IrrigationNeed)
}
