% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/update_pathogen.R
\name{update_pathogen}
\alias{update_pathogen}
\title{Pathogen update}
\usage{
update_pathogen(scenario, pathoName)
}
\arguments{
\item{scenario}{list obtain from create_scenario()}

\item{pathoName}{character name of the pathogens simulated}
}
\value{
scenario_updated list scenario updated with the pathogens to be simulated
}
\description{
Update the configuration with list of pathogen to be simulated according to pathogen ID
}
\examples{
scenario_test <- create_scenario(
  system.file("input_1culture_2pop.xlsx", package = "ambre")
)

scenario_updated <- update_pathogen(scenario = scenario_test,
 pathoName = c("Campylobacter jejuni", "Rotavirus"))
}
