% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query_matrix.R
\name{query_matrix}
\alias{query_matrix}
\title{Query Matrix}
\usage{
query_matrix(config = config_ambre, pathName)
}
\arguments{
\item{config}{list configuration file default value is config_ambre dataset}

\item{pathName}{character Name of the path for which you want to find the ID}
}
\value{
matrixID integer
}
\description{
Retrieve Matrix ID according to path
}
\examples{
query_matrix(pathName = "Consumption of the final product potatoes")
}
