% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/illness_probability_calculation.R
\name{illness_probability_calculation}
\alias{illness_probability_calculation}
\title{Illness probability calculation}
\usage{
illness_probability_calculation(scenario)
}
\arguments{
\item{scenario}{data.frame with risk column}
}
\value{
scenario_updated
}
\description{
Calculate illness probability according to infection probability and pathogen simulated
}
\examples{
library(dplyr)
library(purrr)
scenario_test <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))

scenario_conc <- inflow_concentration(scenario = scenario_test,
 pathogenName = c("Campylobacter jejuni"))

scenario_volume <-
  scenario_conc |>                     
  mutate(
    volume = map(
      .x = config,                                         
      .f = ~ simulate_exposure(config = .x)              
    )
  )

scenario_dose_ini <- initial_dose_calculation(scenario_volume)

scenario_scheme <- update_treatment_scheme(scenario_dose_ini)

scenario_with_logreduc_and_co <- scenario_scheme |> 
  mutate( log_reduction = map(config, simulate_treatment))

scenario_final_dose_and_co_test <- final_dose_calculation(scenario_with_logreduc_and_co)

scenario_inf_proba_and_co <- infection_probability_calculation(scenario_final_dose_and_co_test)

illness_probability_calculation(scenario_inf_proba_and_co)
}
