% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/create_scenario.R
\name{create_scenario}
\alias{create_scenario}
\title{Create Exposure Scenario}
\usage{
create_scenario(filepath, config = config_ambre)
}
\arguments{
\item{filepath}{Path to the Excel file containing input data}

\item{config}{list config file default value config_ambre}
}
\value{
A list containing the scenario data and a placeholder for future data
}
\description{
This function creates exposure scenarios during the two game turns.
}
\examples{
scenario <- create_scenario(system.file("input_cas_apprentissage_complet.xlsx", package = "ambre"))
}
