% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query_pop.R
\name{query_pop}
\alias{query_pop}
\title{Population Query}
\usage{
query_pop(config = config_ambre, popName)
}
\arguments{
\item{config}{list configuration file default value is config_ambre dataset}

\item{popName}{character Name of the population for which you want to find the ID}
}
\value{
popID integer ID of the population define
}
\description{
Query to return population ID from population Name using the database
}
\examples{
query_pop(popName = "Irrigation staff")
}
