% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/update_treatment_scheme.R
\name{update_treatment_scheme}
\alias{update_treatment_scheme}
\title{Update treatment scheme}
\usage{
update_treatment_scheme(scenario, initial_situation = TRUE)
}
\arguments{
\item{scenario}{created with function create_scenario}

\item{initial_situation}{boolean to retrieve simulate treatment train if TRUE or from Barrier train if FALSE}
}
\value{
updated_scenario
}
\description{
Update treatment scheme list in config data frame according to scenario define
}
\examples{
scenario_test <- create_scenario(
  system.file("input_cas_apprentissage_complet.xlsx", package = "ambre")
)
scenario_ini <- update_treatment_scheme(scenario_test, initial_situation = TRUE)
scenario_supp <- update_treatment_scheme(scenario_test, initial_situation = FALSE)
}
