% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/query_volume.R
\name{query_volume}
\alias{query_volume}
\title{Query volume}
\usage{
query_volume(pathID)
}
\arguments{
\item{pathID}{integer ID of the path for which we want to retrieve the volume min and max values}
}
\value{
volume
}
\description{
Retrieve min and max volume values according to path defined in the scenario (database ambre_volume)
}
\examples{
query_volume(pathID = 1)
}
