% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_tbl_risk.R
\name{get_tbl_risk}
\alias{get_tbl_risk}
\title{Get table risk}
\usage{
get_tbl_risk(scenario)
}
\arguments{
\item{scenario}{data.frame with columns inflow concentration, final dose and volume}
}
\value{
tbl_risk
}
\description{
Get table risk to calculate infection probability
}
\examples{

library(dplyr)
library(purrr)
scenario_test <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))

scenario_conc <- inflow_concentration(scenario = scenario_test,
 pathogenName = c("Campylobacter jejuni", "Escherichia coli"))

scenario_volume <-
  scenario_conc |>                     
  mutate(
    volume = map(
      .x = config,                                         
      .f = ~ simulate_exposure(config = .x)              
    )
  )

scenario_dose_ini <- initial_dose_calculation(scenario_volume)

scenario_scheme <- update_treatment_scheme(scenario_dose_ini)

scenario_with_logreduc_and_co <- scenario_scheme |> 
  mutate( log_reduction = map(config, simulate_treatment))

scenario_final_dose_and_co_test <- final_dose_calculation(scenario_with_logreduc_and_co)
tbl_risk_test <- get_tbl_risk(scenario_final_dose_and_co_test)
}
