% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_volumes.R
\name{plot_volumes}
\alias{plot_volumes}
\title{Plot volume}
\usage{
plot_volumes(scenario)
}
\arguments{
\item{scenario}{data.frame with volume column obtained with simulate_exposure function}
}
\value{
plot
}
\description{
Boxplot of the volume of exposition for each population exposed
}
\examples{
library(dplyr)
library(purrr)
scenario_test <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))

scenario_conc <- inflow_concentration(scenario = scenario_test,
 pathogenName = c("Campylobacter jejuni"))

scenario_volume <-
  scenario_conc |>                     
  mutate(
    volume = map(
      .x = config,                                         
      .f = ~ simulate_exposure(config = .x)              
    )
  )

plot_volumes(scenario_volume)
}
