% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simulate_inflow.R
\name{simulate_inflow}
\alias{simulate_inflow}
\title{Simulate: inflow}
\usage{
simulate_inflow(config, debug = TRUE, lean = FALSE)
}
\arguments{
\item{config}{list contained in the scenario object}

\item{debug}{print debug information (default: TRUE)}

\item{lean}{if \code{TRUE}, only the "events" are returned (in a reduced
version, i.e. without column \code{PathogenName} and with all ID columns
being of class \code{integer}), otherwise a list with the events in element
\code{events}" and the corresponding parameters in element \code{paras}.
The default is \code{FALSE}, i.e. events and parameters are returned in a
list.}
}
\value{
list with parameters of user defined random distribution and
corresponding values
}
\description{
This function does the same thing as kwb.utils::simulate_inflow(),
but it is bundled with \emph{ambre} to avoid a hard dependency on the
unmaintained package.
}
\details{
Simulate pathogen concentrations
}
\examples{
# Example usage of simulate_inflow
scenario_test <- create_scenario(system.file("input_1culture_2pop.xlsx", package = "ambre"))
scenario_updated <- update_pathogen(scenario = scenario_test,
 pathoName = c("Campylobacter jejuni", "Rotavirus"))

# Call simulate_inflow with the sample config
result_1 <- simulate_inflow(config = scenario_updated$config[[1]], debug = FALSE)

# Print the results
cat("Parameters used for simulation:")
print(result_1$paras)

# Example with lean = TRUE
lean_result_1 <- simulate_inflow(config = scenario_updated$config[[1]], debug = FALSE, lean = TRUE)
cat("Lean result (only events):")
print(lean_result_1)
}
\references{
Sonnenberg H (2024). kwb.utils: General Utility Functions Developed at KWB. R package version 0.15.0
URL: \url{https://github.com/kwb-r/kwb.utils}
(MIT Licence)
}
